@@ -256,7 +256,7 @@ def process_document_tree(parsing_spec, dataset_info, document_info):
 
       # common processing for any value
       custom_value_text = value.text.strip()
-      custom_value_text = re.sub(r'\n +', ' ', custom_value_text)
+      custom_value_text = re.sub(r'\r?\n +', ' ', custom_value_text)
       custom_value_text = re.sub(r'  +', ' ',  custom_value_text)
 
       # only process requested keys
